@@ -13,7 +13,7 @@
 
 package IO::Socket::SSL;
 
-our $VERSION = '2.027';
+our $VERSION = '2.028';
 
 use IO::Socket;
 use Net::SSLeay 1.46;
@@ -2783,6 +2783,15 @@ sub new {
 }
 
 
+sub del_session {
+    my ($self, $key) = @_;
+    my $val = $self->{$key} or return;
+    Net::SSLeay::SESSION_free($val->{session});
+    $val->{prev}{next} = $val->{next};
+    $val->{next}{prev} = $val->{prev};
+    $self->{_head} = $val->{next} if $val == $self->{_head};
+}
+
 sub get_session {
     my ($self, $key) = @_;
     my $session = $self->{$key} || return;
